==> phpsysinfo_2.5.1.orig.tar.gz: phpsysinfo/includes/lang/lv.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: lv.php,v 1.8 2005/12/07 15:02:11 bigmichi1 Exp $

$text['title']          = 'Sistmas informcija';

$text['vitals']         = 'Galvenie rdtji';
$text['hostname']       = 'Hosta vrds';
$text['ip']             = 'IP Adrese';
$text['kversion']       = 'Kernea versija';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Neprtrauktais darba laiks';
$text['users']          = 'Lietotji';
$text['loadavg']        = 'Vidjie ieldes rdtji';

$text['hardware']       = 'Aparatra';
$text['numcpu']         = 'Procesors';
$text['cpumodel']       = 'Modelis';
$text['cpuspeed']       = 'ipa MHz';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Ke atmia';
$text['bogomips']       = 'Sistmas "Bogomips"';

$text['pci']            = 'PCI ierces';
$text['ide']            = 'IDE ierces';
$text['scsi']           = 'SCSI ierces';
$text['usb']            = 'USB ierces';

$text['netusage']       = 'Tkla informcija';
$text['device']         = 'Ierce';
$text['received']       = 'Saemts';
$text['sent']           = 'Aizstts';
$text['errors']         = 'Kdas/Zaudts paketes';

$text['connections']    = 'Established Network Connections';

$text['memusage']       = 'Atmias lietojums';
$text['phymem']         = 'Operatv atmia';
$text['swap']           = 'Swap atmia';

$text['fs']             = 'Cietie diski';
$text['mount']          = 'Mounta vieta';
$text['partition']      = 'Partcija';

$text['percent']        = 'Aizemts procentos';
$text['type']           = 'Tips';
$text['free']           = 'Brvs';
$text['used']           = 'Aizemts';
$text['size']           = 'Ietilpba';
$text['totals']         = 'Kop';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'nav';

$text['capacity']       = 'Ietilpba';

$text['template']       = 'Sagatave';
$text['language']       = 'Valoda';
$text['submit']         = 'Apstiprint';
$text['created']        = 'Autors';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'dienas';
$text['hours']          = 'stundas';
$text['minutes']        = 'mintes';

$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= '- Kernel + applications';
$text['buffers']	= '- Buffers';
$text['cached']		= '- Cached';

?>

==> phpsysinfo_2.5.2.orig.tar.gz: phpsysinfo/includes/lang/lv.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: lv.php,v 1.10 2006/06/05 11:48:16 bigmichi1 Exp $

$text['title']          = 'Sistmas informcija';

$text['vitals']         = 'Galvenie rdtji';
$text['hostname']       = 'Hosta vrds';
$text['ip']             = 'IP Adrese';
$text['kversion']       = 'Kernea versija';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Neprtrauktais darba laiks';
$text['users']          = 'Lietotji';
$text['loadavg']        = 'Vidjie ieldes rdtji';

$text['hardware']       = 'Aparatra';
$text['numcpu']         = 'Procesors';
$text['cpumodel']       = 'Modelis';
$text['cpuspeed']       = 'ipa MHz';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Ke atmia';
$text['bogomips']       = 'Sistmas "Bogomips"';

$text['pci']            = 'PCI ierces';
$text['ide']            = 'IDE ierces';
$text['scsi']           = 'SCSI ierces';
$text['usb']            = 'USB ierces';

$text['netusage']       = 'Tkla informcija';
$text['device']         = 'Ierce';
$text['received']       = 'Saemts';
$text['sent']           = 'Aizstts';
$text['errors']         = 'Kdas/Zaudts paketes';

$text['connections']    = 'Established Network Connections';

$text['memusage']       = 'Atmias lietojums';
$text['phymem']         = 'Operatv atmia';
$text['swap']           = 'Swap atmia';

$text['fs']             = 'Cietie diski';
$text['mount']          = 'Mounta vieta';
$text['partition']      = 'Partcija';

$text['percent']        = 'Aizemts procentos';
$text['type']           = 'Tips';
$text['free']           = 'Brvs';
$text['used']           = 'Aizemts';
$text['size']           = 'Ietilpba';
$text['totals']         = 'Kop';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'nav';

$text['capacity']       = 'Ietilpba';

$text['template']       = 'Sagatave';
$text['language']       = 'Valoda';
$text['submit']         = 'Apstiprint';
$text['created']        = 'Autors';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'dienas';
$text['hours']          = 'stundas';
$text['minutes']        = 'mintes';

$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&ordm;C';
$text['degreeF']        = '&ordm;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

?>
